@@ -52,4 +52,14 @@ class Quux extends Corge {
     method quux {}
 }
 
+role SecondRole {}
+
+class MultiRole with Role with SecondRole {
+    method required_thing {}
+}
+
+class MultiRole2 with (Role, SecondRole) {
+    method required_thing {}
+}
+
 1;
